opendaq-python
==============
Python binding for openDAQ hardware.

openDAQ libraries and examples are compatible with Python 2.7.

Python 3.X is not yet supported.

See usage.rst for additional support.

* * *

OpenDAQ is an open source data acquisition instrument, which provides user with
several physical interaction capabilities such as analog inputs and outputs,
digital inputs and outputs, timers and counters.

By means of an USB connection, openDAQ brings all the information that it
captures to a host computer, where you can decide how to process, display and
store it. Several demos and examples are provided in website's support page.
(http://www.open-daq.com/paginas/support)

Please, go to http://www.open-daq.com for additional info.
For support, e-mail to support@open-daq.com

